@@ -6,7 +6,7 @@ import sys, traceback, getopt, types, textwrap, inspect, os
 from itertools import imap
 
 __all__ = ['command', 'dispatch']
-__version__ = '1.0'
+__version__ = '1.2'
 __author__ = 'Alexander Solovyov'
 __email__ = 'piranha@piranha.org.ua'
 
@@ -181,7 +181,7 @@ def help_(cmdtable, globalopts):
                 if shortlist and not cmd.startswith('^'):
                     continue  # short help contains only marked commands
                 cmd = cmd.lstrip('^~')
-                doc = info[0].__doc__ or '(no help text available)'
+                doc = info[0].__doc__.strip() or '(no help text available)'
                 hlp[cmd] = doc.splitlines()[0].rstrip()
 
             hlplist = sorted(hlp)
@@ -616,11 +616,14 @@ compctl -K _opster_completion %s
     }
 
 @command(name='_completion', hide=True)
-def completion(type=('t', 'bash', 'Completion type (bash or zsh)')):
+def completion(type=('t', 'bash', 'Completion type (bash or zsh)'),
+               # kwargs will catch every global option, which we get
+               # anyway, because middleware is skipped
+               **kwargs):
     """Outputs completion script for bash or zsh."""
 
     prog_name = os.path.split(sys.argv[0])[1]
-    print COMPLETIONS[type] % prog_name
+    print COMPLETIONS[type].strip() % prog_name
 
 # --------
 # Exceptions
